@@ -5,7 +5,7 @@ if nargin<3
 end
 
 if isempty(var) || ~isscalar(var) || ~isnumeric(var) || var<0 || rem(var,1)~=0 
-   error('%s: %s should be a positive integer.',upper(callfun),varname);
+   error('%s: %s should be non-negative integer.',upper(callfun),varname);
 end
 
 %-*- texinfo -*-
@@ -15,8 +15,8 @@ end
 %@strong{Url}: @url{http://ltfat.github.io/doc/comp/complainif_notnonnegint.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.3.1
+% Copyright (C) 2005-2022 Peter L. Soendergaard <peter@sonderport.dk> and others.
+% This file is part of LTFAT version 2.5.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
