@@ -7,8 +7,8 @@ function test_failed=test_demos
 %@strong{Url}: @url{http://ltfat.github.io/doc/testing/test_demos.html}
 %@end deftypefn
 
-% Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.3.1
+% Copyright (C) 2005-2022 Peter L. Soendergaard <peter@sonderport.dk> and others.
+% This file is part of LTFAT version 2.5.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -36,12 +36,12 @@ function test_failed=test_demos
      % variable name clash
      rundemo(filename(1:end-2));
      
-     
-  end;
+  end
   
   
 function rundemo(demoname)
    close all;
    eval(demoname);
+   clear all; 
 
 
